@@ -24,7 +24,7 @@
 */
 #include <Plasma/Applet>
 #include <Plasma/Label>
-#include <skgservices.h>
+#include "skgservices.h"
 #include <QGraphicsLinearLayout>
 
 class QGraphicsGridLayout;
