@@ -93,6 +93,7 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     //
     KAction* goHome = KStandardAction::home(this, SLOT(goHome()), actionCollection());
+    goHome->setPriority(QAction::LowPriority);
     if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("go_home", goHome);
 
     //Bookmark
@@ -108,6 +109,7 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_bookmarkAction->setStickyMenu(false);
     m_bookmarkAction->setDelayed(false);
     m_bookmarkAction->setData(0);
+    m_bookmarkAction->setPriority(QAction::LowPriority);
 
     //bookmarkAction=KStandardAction::redo(this, SLOT(actionRedo()), actionCollection());
     if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit-bookmark", m_bookmarkAction);
