@@ -197,7 +197,9 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
     int nbTab = SKGMainPanel::getMainPanel()->countPages();
     if (nbTab) {
         setForcusOn = nbTab - 1;
-        if (m_middleClick) {
+
+        SKGTabPage* cPage = SKGMainPanel::getMainPanel()->currentPage();
+        if (m_middleClick || (cPage && cPage->isPin())) {
             setForcusOn = nbTab;
         } else {
             setForcusOn = SKGMainPanel::getMainPanel()->currentPageIndex();
