@@ -189,6 +189,10 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
                         for (int c = 1; c <= pageCopies; ++c) {
                             QWidget* widget = pages.at(pageToTreat - 1);
                             if (widget) {
+                                //Save palette
+                                QPalette previousPalette = widget->palette();
+
+                                //Draw in a picture with white background
                                 QImage image(widget->size(), QImage::Format_ARGB32);
                                 QPainter painter2(&image);
                                 QPalette palette;
@@ -197,6 +201,10 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
                                 widget->render(&painter2);
                                 painter2.end();
 
+                                //Restore palette
+                                widget->setPalette(previousPalette);
+
+                                //Print the picture
                                 QSize size = image.size();
                                 size.scale(rect.size(), Qt::KeepAspectRatio);
                                 painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
