@@ -122,7 +122,9 @@ SKGError SKGImportPluginKmy::importFile()
                     if (!err && !unitObj.exist()) {
                         //Creation of unit
                         err = unitObj.setName(unitName);
-                        if (!err) err = unitObj.setSymbol(security.attribute("symbol"));
+                        QString symbol = security.attribute("symbol");
+                        if (symbol.isEmpty()) symbol = unitName;
+                        if (!err) err = unitObj.setSymbol(symbol);
                         if (!err) err = unitObj.setCountry(security.attribute("trading-market"));
                         if (!err) err = unitObj.setType(SKGUnitObject::SHARE);
                         if (!err) {
@@ -349,6 +351,7 @@ SKGError SKGImportPluginKmy::importFile()
                     if (!err) err = operationObj.setImportID("KMY-" % operation.attribute("id"));
                     if (!err) {
                         QString unitName = operation.attribute("commodity");
+                        if (unitName.isEmpty()) unitName = "??";
                         SKGUnitObject unit(m_importer->getDocument());
                         err = unit.setName(unitName);
                         if (!err) err = unit.setSymbol(unitName);
@@ -602,7 +605,7 @@ SKGError SKGImportPluginKmy::importFile()
 
             //Step 8-Remove useless account and temporary account
             {
-                if (!err) err = kmymoneyTemporaryAccount.remove(false);
+                if (!err) err = kmymoneyTemporaryAccount.remove(false, true);
                 if (!err) err = m_importer->getDocument()->executeSqliteOrder("DELETE FROM account WHERE rd_bank_id=" % SKGServices::intToString(bank.getID()) % " AND (SELECT COUNT(1) FROM operation WHERE operation.rd_account_id=account.id)=0");
             }
             if (!err) err = m_importer->getDocument()->stepForward(8);
