@@ -68,11 +68,9 @@ SKGError SKGImportPluginSkg::importFile()
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginSkg::importFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     SKGDocumentBank docOrigin;
-    err = docOrigin.load(iFileName, m_parameters["password"]);
+    err = docOrigin.load(m_importer->getFileName(), m_parameters["password"]);
     if (!err) {
         QMap<QString, SKGObjectBase> mapOriginNew;
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "SKG"), 10);
@@ -462,8 +460,6 @@ SKGError SKGImportPluginSkg::exportFile()
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginSkg::exportFile", err);
-    QString iFileName = m_importer->getFileName();
-    SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     QString tempFile = m_importer->getDocument()->getCurrentTemporaryFile();
     if (m_importer->getDocument()->getCurrentFileName().isEmpty()) {
@@ -487,18 +483,18 @@ SKGError SKGImportPluginSkg::exportFile()
     }
 
     //Copy file to file
-    QFile::remove(iFileName);
-    if (QFileInfo(m_importer->getFileName()).suffix().toUpper() == "SQLITE") {
-        if (!KIO::NetAccess::file_copy(tempFile, iFileName)) {
+    QFile::remove(m_importer->getLocalFileName());
+    if (QFileInfo(m_importer->getLocalFileName()).suffix().toUpper() == "SQLITE") {
+        if (!KIO::NetAccess::file_copy(tempFile, m_importer->getLocalFileName())) {
             //Set error message
             err.setReturnCode(ERR_FAIL);
-            err.setMessage(i18nc("An error message", "Creation file '%1' failed", iFileName));
+            err.setMessage(i18nc("An error message", "Creation file '%1' failed", m_importer->getLocalFileName()));
         }
     } else {
-        err = SKGServices::cryptFile(tempFile, iFileName, "", true, m_importer->getDocument()->getDocumentHeader());
+        err = SKGServices::cryptFile(tempFile, m_importer->getLocalFileName(), "", true, m_importer->getDocument()->getDocumentHeader());
         if (!err) {
             SKGDocumentBank doc;
-            err = doc.load(iFileName);
+            err = doc.load(m_importer->getLocalFileName());
             if (!err) err = doc.removeAllTransactions();
             if (!err) err = doc.save();
         }
