@@ -22,7 +22,7 @@
 #include "skgimportpluginxml.h"
 #include "skgtraces.h"
 #include "skgdocumentbank.h"
-#include <skgservices.h>
+#include "skgservices.h"
 
 #include <klocale.h>
 #include <ksavefile.h>
