@@ -78,6 +78,12 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(SKGDocument* iDocument)
     connect(m_menuCreditCard, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuCreditCard);
 
+    m_menuSaving = new KAction(i18nc("Noun, a type of account", "Saving"), this);
+    m_menuSaving->setCheckable(true);
+    m_menuSaving->setChecked(true);
+    connect(m_menuSaving, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    addAction(m_menuSaving);
+
     m_menuInvestment = new KAction(i18nc("Noun, a type of account", "Investment"), this);
     m_menuInvestment->setCheckable(true);
     m_menuInvestment->setChecked(true);
@@ -113,6 +119,7 @@ SKGAccountBoardWidget::~SKGAccountBoardWidget()
     m_menuAssets = NULL;
     m_menuCurrent = NULL;
     m_menuCreditCard = NULL;
+    m_menuSaving = NULL;
     m_menuInvestment = NULL;
     m_menuWallet = NULL;
     m_menuLoan = NULL;
@@ -131,6 +138,7 @@ QString SKGAccountBoardWidget::getState()
     root.setAttribute("menuAssets", m_menuAssets && m_menuAssets->isChecked() ? "Y" : "N");
     root.setAttribute("menuCurrent", m_menuCurrent && m_menuCurrent->isChecked() ? "Y" : "N");
     root.setAttribute("menuCreditCard", m_menuCreditCard && m_menuCreditCard->isChecked() ? "Y" : "N");
+    root.setAttribute("menuSaving", m_menuSaving && m_menuSaving->isChecked() ? "Y" : "N");
     root.setAttribute("menuInvestment", m_menuInvestment && m_menuInvestment->isChecked() ? "Y" : "N");
     root.setAttribute("menuWallet", m_menuWallet && m_menuWallet->isChecked() ? "Y" : "N");
     root.setAttribute("m_menuLoan", m_menuLoan && m_menuLoan->isChecked() ? "Y" : "N");
@@ -150,6 +158,7 @@ void SKGAccountBoardWidget::setState(const QString& iState)
     if (m_menuAssets) m_menuAssets->setChecked(root.attribute("menuAssets") != "N");
     if (m_menuCurrent) m_menuCurrent->setChecked(root.attribute("menuCurrent") != "N");
     if (m_menuCreditCard) m_menuCreditCard->setChecked(root.attribute("menuCreditCard") != "N");
+    if (m_menuSaving) m_menuSaving->setChecked(root.attribute("menuSaving") != "N");
     if (m_menuInvestment) m_menuInvestment->setChecked(root.attribute("menuInvestment") != "N");
     if (m_menuWallet) m_menuWallet->setChecked(root.attribute("menuWallet") != "N");
     if (m_menuLoan) m_menuLoan->setChecked(root.attribute("m_menuLoan") != "N");
@@ -200,6 +209,10 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                         if (!wc.isEmpty()) wc += " OR ";
                         wc += "t_type='D'";
                     }
+                    if (m_menuSaving && m_menuSaving->isChecked()) {
+                        if (!wc.isEmpty()) wc += " OR ";
+                        wc += "t_type='S'";
+                    }
                     if (m_menuInvestment && m_menuInvestment->isChecked()) {
                         if (!wc.isEmpty()) wc += " OR ";
                         wc += "t_type='I'";
