@@ -29,7 +29,7 @@
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skginterfaceplugin.h"
-#include <skgtablewithgraph.h>
+#include "skgtablewithgraph.h"
 
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
@@ -132,17 +132,18 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     SKGWidgetSelector::SKGListQWidget list;
     list.push_back(ui.SKGEditionWidget);
     list.push_back(ui.SKGEditionButtonswidget);
-    ui.kWidgetSelector->addButton(KIcon("configure"), i18n("Edition"), i18n("Display the account edition panel"), list);
+    ui.kWidgetSelector->addButton(KIcon("configure"), i18n("Edit"), i18n("Display the account edit panel"), list);
 
     //Add NLS values for type of account
     //C=current D=credit card P=passif (for objects) I=Investment O=other
-    ui.kAccountCreatorType->addItem(KIcon("view-bank-account-savings"), i18nc("Noun, a type of account", "Current"), 0);
-    ui.kAccountCreatorType->addItem(KIcon("view-credit-card-account"), i18nc("Noun, a type of account", "Credit card"), 1);
-    ui.kAccountCreatorType->addItem(KIcon("view-stock-account"), i18nc("Noun, a type of account", "Investment"), 2);
-    ui.kAccountCreatorType->addItem(KIcon("view-loan-asset"), i18nc("Noun, a type of account", "Assets"), 3);
-    ui.kAccountCreatorType->addItem(KIcon("view-loan-asset"), i18nc("Noun, a type of account", "Loan"), 6);
-    ui.kAccountCreatorType->addItem(KIcon("kwalletmanager"), i18nc("Noun, a type of account", "Wallet"), 5);
-    ui.kAccountCreatorType->addItem(i18nc("Noun, a type of account", "Other"), 4);
+    ui.kAccountCreatorType->addItem(KIcon("view-bank-account-savings"), i18nc("Noun, a type of account", "Current"), SKGAccountObject::CURRENT);
+    ui.kAccountCreatorType->addItem(KIcon("view-credit-card-account"), i18nc("Noun, a type of account", "Credit card"), SKGAccountObject::CREDITCARD);
+    ui.kAccountCreatorType->addItem(KIcon("view-bank-account-savings"), i18nc("Noun, a type of account", "Saving"), SKGAccountObject::SAVING);
+    ui.kAccountCreatorType->addItem(KIcon("view-stock-account"), i18nc("Noun, a type of account", "Investment"), SKGAccountObject::INVESTMENT);
+    ui.kAccountCreatorType->addItem(KIcon("view-loan-asset"), i18nc("Noun, a type of account", "Assets"), SKGAccountObject::ASSETS);
+    ui.kAccountCreatorType->addItem(KIcon("view-loan-asset"), i18nc("Noun, a type of account", "Loan"), SKGAccountObject::LOAN);
+    ui.kAccountCreatorType->addItem(KIcon("kwalletmanager"), i18nc("Noun, a type of account", "Wallet"), SKGAccountObject::WALLET);
+    ui.kAccountCreatorType->addItem(i18nc("Noun, a type of account", "Other"), SKGAccountObject::OTHER);
 
     //Bind account creation view
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_account_display", "1=0", this, "", false));
@@ -188,7 +189,6 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
                 } else {
                     ui.kAccountCreatorIcon->addItem(QIcon(dirLogo.absoluteFilePath(line)), bankName, "");
                 }
-
             }
         }
         ui.kAccountCreatorIcon->addItem(KIcon("document-open-folder"), i18nc("Other type of bank account", "Other..."));
@@ -199,7 +199,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
-    // Activate the edition panel per default
+    // Activate the edit panel per default
     ui.kWidgetSelector->setSelectedMode(0);
 
     //Refresh
@@ -373,7 +373,7 @@ void SKGBankPluginWidget::onIconChanged()
         } else ui.kAccountCreatorIcon->setCurrentIndex(c - 1);
     }
 
-    onAccountCreatorModified();
+    ui.kAccountCreatorBank->setText(ui.kAccountCreatorIcon->currentIndex() != 0 ? ui.kAccountCreatorIcon->currentText() : "");
 }
 
 
@@ -384,7 +384,7 @@ void SKGBankPluginWidget::onAccountCreatorModified()
     bool activatedForWallet = ui.kWidgetSelector->getSelectedMode() != -1 &&
                               ui.kAccountCreatorAccount->text().length() > 0 &&
                               ui.kUnitEdit->currentText().length() > 0 &&
-                              (ui.kAmountEdit->valid() || ui.kAmountEdit->text().isEmpty());
+                              (ui.kAmountEdit->valid() || ui.kAmountEdit->text().isEmpty() || ui.kAmountEdit->text() == NOUPDATE);
     bool activated = activatedForWallet &&
                      ui.kAccountCreatorBank->text().length() > 0;
     bool wallet = ((SKGAccountObject::AccountType)(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()) == SKGAccountObject::WALLET);
@@ -400,11 +400,6 @@ void SKGBankPluginWidget::onAccountCreatorModified()
     ui.kAccountCreatorAddress->setVisible(!wallet);
     ui.kAgencyAddressLbl->setVisible(!wallet);
 
-    //Facilitate bank name
-    if (ui.kAccountCreatorBank->text().isEmpty()) {
-        ui.kAccountCreatorBank->setText(ui.kAccountCreatorIcon->currentIndex() != 0 ? ui.kAccountCreatorIcon->currentText() : "");
-    }
-
     //Facilitate bank number
     if (ui.kAccountCreatorBankNumber->text().isEmpty()) {
         QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
@@ -708,7 +703,7 @@ void SKGBankPluginWidget::refreshInfoZone()
             QString s2 = doc->formatMoney(v2, primary);
             QString s3 = doc->formatMoney(v3, primary);
             QString s4 = doc->formatMoney(v4, primary);
-            ui.kInfo->setText(i18nc("Information on an account's status : Balance is the current amount of money on the account, Cleared is the amount of money on your last bank's statement, In Transit is the differences between these two values", "Today balance : %1     Balance : %2     Cleared : %3     In Transit : %4", s1, s2, s3, s4));
+            ui.kInfo->setText(i18nc("Information on an account's status : Balance is the current amount of money on the account, Checked is the amount of money on your last bank's statement, To be Checked is the differences between these two values", "Today balance : %1     Balance : %2     Checked : %3     To be Checked : %4", s1, s2, s3, s4));
 
             SKGServices::SKGUnitInfo secondaryUnit = doc->getSecondaryUnit();
             if (!secondaryUnit.Symbol.isEmpty() && secondaryUnit.Value) {
@@ -717,7 +712,7 @@ void SKGBankPluginWidget::refreshInfoZone()
                 s3 = doc->formatMoney(v3, secondaryUnit);
                 s4 = doc->formatMoney(v4, secondaryUnit);
             }
-            ui.kInfo->setToolTip(i18nc("Information on an account's status : Balance is the current amount of money on the account, Cleared is the amount of money on your last bank's statement, In Transit is the differences between these two values", "<p>Today balance : %1 < / p > <p>Balance : %2 < / p > <p>Cleared : %3 < / p > <p>In Transit : %4 < / p > ", s1, s2, s3, s4));
+            ui.kInfo->setToolTip(i18nc("Information on an account's status : Balance is the current amount of money on the account, Checked is the amount of money on your last bank's statement, To be Checked is the differences between these two values", "<p>Today balance : %1 < / p > <p>Balance : %2 < / p > <p>Checked : %3 < / p > <p>To be Checked : %4 < / p > ", s1, s2, s3, s4));
         }
     }
 }
