@@ -20,6 +20,7 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgbudgetpluginwidget.h"
+#include "skgbudgetdelegate.h"
 #include "skgmainpanel.h"
 #include "skgobjectmodel.h"
 #include "skgbudgetobject.h"
@@ -123,6 +124,8 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Current"), SKGBudgetRuleObject::CURRENT);
     ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Current year"), SKGBudgetRuleObject::YEAR);
 
+    ui.kView->getView()->setItemDelegate(new SKGBudgetDelegate(ui.kView->getView(), getDocument()));
+
     SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
     if (doc) {
         ui.kUnitCmb->addItem("%");
@@ -153,19 +156,19 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGManualSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(KIcon("user-properties"), i18n("Manual"), i18n("Display the edition panel for standard budget"), list);
+        ui.kWidgetSelector->addButton(KIcon("user-properties"), i18n("Manual"), i18n("Display the edit panel for standard budget"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGAutoSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(KIcon("games-solve"), i18n("Auto"), i18n("Display the edition panel for automatic budgets"), list);
+        ui.kWidgetSelector->addButton(KIcon("games-solve"), i18n("Auto"), i18n("Display the edit panel for automatic budgets"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGRuleSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(KIcon("view-financial-transfer"), i18n("Rules"), i18n("Display the edition panel for rules"), list);
+        ui.kWidgetSelector->addButton(KIcon("view-financial-transfer"), i18n("Rules"), i18n("Display the edit panel for rules"), list);
     }
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onBtnModeClicked(int)));
 
