@@ -24,12 +24,11 @@
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgobjectbase.h"
-#include <skgmainpanel.h>
+#include "skgmainpanel.h"
 
 #include <QDomDocument>
 
 #include <kaction.h>
-#include <kcolorscheme.h>
 
 SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     : SKGWidget(iDocument)
@@ -43,25 +42,21 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     ui.kIncome_previousLabel->setText("<a href=\"IP\">" % ui.kIncome_previousLabel->text() % "</a>");
     ui.kExpense_previousLabel->setText("<a href=\"EP\">" % ui.kExpense_previousLabel->text() % "</a>");
 
-    //Define color style
-    KColorScheme scheme(QPalette::Normal);
-    QString negative = scheme.foreground(KColorScheme::NegativeText).color().name();
-    QString neutral = scheme.foreground(KColorScheme::NeutralText).color().name();
-    QString positive = scheme.foreground(KColorScheme::PositiveText).color().name();
-
-    m_negativeStyleSheet = QString(" QProgressBar { text-align: center; padding: 0.5px;} QProgressBar::chunk {text-align: center; border-radius:4px; background-color: ") % negative % ";}" % ui.kIncome->styleSheet();
-    m_neutralStyleSheet = QString(" QProgressBar { text-align: center; padding: 0.5px;} QProgressBar::chunk {text-align: center; border-radius:4px; background-color: ") % neutral % ";}" % ui.kIncome->styleSheet();
-    m_positiveStyleSheet = QString(" QProgressBar { text-align: center; padding: 0.5px;} QProgressBar::chunk {text-align: center; border-radius:4px; background-color: ") % positive % ";}" % ui.kIncome->styleSheet();
-
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    m_menuTransfert = new KAction(i18nc("Noun, a type of account", "Transfers"), this);
+    m_menuTransfert = new KAction(i18nc("Noun, a type of operations", "Transfers"), this);
     m_menuTransfert->setCheckable(true);
     m_menuTransfert->setChecked(true);
     connect(m_menuTransfert, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuTransfert);
 
+    m_menuTracked = new KAction(i18nc("Noun, a type of operations", "Tracked"), this);
+    m_menuTracked->setCheckable(true);
+    m_menuTracked->setChecked(true);
+    connect(m_menuTracked, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    addAction(m_menuTracked);
+
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
@@ -70,6 +65,7 @@ SKGOperationBoardWidget::~SKGOperationBoardWidget()
 {
     SKGTRACEIN(10, "SKGOperationBoardWidget::~SKGOperationBoardWidget");
     m_menuTransfert = NULL;
+    m_menuTracked = NULL;
 }
 
 QString SKGOperationBoardWidget::getState()
@@ -79,6 +75,7 @@ QString SKGOperationBoardWidget::getState()
     doc.appendChild(root);
 
     root.setAttribute("menuTransfert", m_menuTransfert && m_menuTransfert->isChecked() ? "Y" : "N");
+    root.setAttribute("menuTracked", m_menuTracked && m_menuTracked->isChecked() ? "Y" : "N");
     return doc.toString();
 }
 
@@ -88,6 +85,7 @@ void SKGOperationBoardWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
     if (m_menuTransfert) m_menuTransfert->setChecked(root.attribute("menuTransfert") != "N");
+    if (m_menuTracked) m_menuTracked->setChecked(root.attribute("menuTracked") != "N");
 
     dataModified("", 0);
 }
@@ -105,7 +103,7 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
     if (iLink.startsWith(QLatin1String("I"))) wc = wc % " AND t_TYPEEXPENSE='+'";
     else wc = wc % " AND t_TYPEEXPENSE='-'";
 
-    wc = wc % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : " AND t_TRANSFER='N'");
+    wc = wc % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : " AND t_TRANSFER='N'") % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND r_refund_id=0");
 
     doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
     QDomElement root = doc.documentElement();
@@ -119,6 +117,7 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
     else if (iLink == "IP") title = i18nc("Title of a list of operations", "Incomes of previous month");
     else if (iLink == "EP") title = i18nc("Title of a list of operations", "Expenses of previous month");
 
+    if (m_menuTracked && m_menuTracked->isChecked() == false) root.setAttribute("operationTable", "v_operation_consolidated");
     root.setAttribute("operationWhereClause", wc);
     root.setAttribute("title", title);
     root.setAttribute("title_icon", "view-financial-list");
@@ -147,7 +146,10 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
 
             SKGStringListList listTmp;
             SKGError err = getDocument()->executeSelectSqliteOrder(
-                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') " % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : "AND t_TRANSFER='N'") % " group by d_DATEMONTH, t_TYPEEXPENSE",
+                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_consolidated WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') "
+                               % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : "AND t_TRANSFER='N'")
+                               % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND r_refund_id=0")
+                               % " group by d_DATEMONTH, t_TYPEEXPENSE",
                                listTmp);
             if (!err) {
                 double income_previous_month = 0;
@@ -200,12 +202,12 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 }
 
                 //Change colors
-                ui.kIncome->setStyleSheet(m_positiveStyleSheet);
-                ui.kIncome_previous->setStyleSheet(m_positiveStyleSheet);
-                ui.kExpense->setStyleSheet(m_negativeStyleSheet);
-                ui.kExpense_previous->setStyleSheet(m_negativeStyleSheet);
-                ui.kSaving->setStyleSheet(income_month - expense_month < 0 ? m_negativeStyleSheet : income_month - expense_month < 0.1 * income_month ? m_neutralStyleSheet : m_positiveStyleSheet);
-                ui.kSaving_previous->setStyleSheet(income_previous_month - expense_previous_month < 0 ? m_negativeStyleSheet : income_previous_month - expense_previous_month < 0.1 * income_previous_month ? m_neutralStyleSheet : m_positiveStyleSheet);
+                ui.kIncome->setLimits(0, 0, max);
+                ui.kIncome_previous->setLimits(0, 0, max);
+                ui.kExpense->setLimits(max, -1, -1);
+                ui.kExpense_previous->setLimits(max, -1, -1);
+                ui.kSaving->setLimits(income_month - expense_month < 0 ? max : 0, 0.1 * income_month, max);
+                ui.kSaving_previous->setLimits(income_previous_month - expense_previous_month < 0 ? max : 0, 0.1 * income_previous_month, max);
             }
 
             //No widget if no account
