@@ -69,10 +69,7 @@ private:
     Ui::skgoperationplugin_board ui;
 
     KAction* m_menuTransfert;
-
-    QString m_negativeStyleSheet;
-    QString m_neutralStyleSheet;
-    QString m_positiveStyleSheet;
+    KAction* m_menuTracked;
 };
 
 #endif // SKGOPERATIONBOARDWIDGET_H
