@@ -906,7 +906,7 @@ SKGAdviceList SKGOperationPlugin::advices() const
         QString rate = result.at(1).at(1);
 
         //Get accounts with too much money
-        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_display WHERE f_RATE<" % rate % " AND t_type='C' AND t_close='N' AND f_CURRENTAMOUNT>-2*(SELECT TOTAL(s.f_CURRENTAMOUNT) FROM v_operation_display s WHERE s.rd_account_id=v_account_display.id AND s.t_TYPEEXPENSE='-' AND s.d_DATEMONTH = strftime('%Y-%m',date('now','start of month', '-1 MONTH')))", result);
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_display WHERE f_RATE<" % rate % " AND t_type='C' AND t_close='N' AND f_CURRENTAMOUNT>-2*(SELECT TOTAL(s.f_CURRENTAMOUNT) FROM v_operation_display s WHERE s.rd_account_id=v_account_display.id AND s.t_TYPEEXPENSE='-' AND s.d_DATEMONTH = (SELECT strftime('%Y-%m',date('now','start of month', '-1 MONTH'))))", result);
         nb = result.count();
         for (int i = 1; i < nb; ++i) { //Ignore header
             //Get parameters
