@@ -138,7 +138,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
         list.push_back(ui.SKGSmallButtons);
         list.push_back(ui.SKGEditionButtonsWidget);
         list.push_back(ui.SKGSingleOpSection);
-        ui.kWidgetSelector->addButton(KIcon("dialog-ok-apply"), i18n("Standard"), i18n("Display the edition panel for standard operations"), list);
+        ui.kWidgetSelector->addButton(KIcon("dialog-ok-apply"), i18n("Standard"), i18n("Display the edit panel for standard operations"), list);
     }
 
     {
@@ -148,7 +148,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
         list.push_back(ui.SKGSmallButtons);
         list.push_back(ui.SKGEditionButtonsWidget);
         list.push_back(ui.SKGSplitOpSection);
-        ui.kWidgetSelector->addButton(KIcon("split"), i18n("Split"), i18n("Display the edition panel for split operations"), list);
+        ui.kWidgetSelector->addButton(KIcon("split"), i18n("Split"), i18n("Display the edit panel for split operations"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
@@ -159,7 +159,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
         list.push_back(ui.SKGSingleOpSection);
         list.push_back(ui.kTargetAccountEdit);
         list.push_back(ui.kTargetAccountLabel);
-        ui.kWidgetSelector->addButton(KIcon("view-financial-transfer"), i18n("Transfer"), i18n("Display the edition panel for transfers between accounts"), list);
+        ui.kWidgetSelector->addButton(KIcon("view-financial-transfer"), i18n("Transfer"), i18n("Display the edit panel for transfers between accounts"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
@@ -168,7 +168,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
         list.push_back(ui.SKGSmallButtons);
         list.push_back(ui.SKGEditionButtonsWidget);
         list.push_back(ui.SKGSharesSection);
-        ui.kWidgetSelector->addButton(KIcon("view-stock-account"), i18n("Shares"), i18n("Display the edition panel for purchasing or selling shares"), list);
+        ui.kWidgetSelector->addButton(KIcon("view-stock-account"), i18n("Shares"), i18n("Display the edit panel for purchasing or selling shares"), list);
     }
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onBtnModeClicked(int)));
 
@@ -249,14 +249,11 @@ SKGOperationPluginWidget::~SKGOperationPluginWidget()
 QString SKGOperationPluginWidget::currentAccount()
 {
     QStringList accounts = SKGServices::splitCSVLine(ui.kOperationView->getShowWidget()->getState());
-    accounts.removeAll("all");
-    accounts.removeAll("hide");
-    accounts.removeAll("hide6m");
-    accounts.removeAll("hide3m");
-    accounts.removeAll("hide1y");
-    accounts.removeAll("operations");
-    accounts.removeAll("templates");
-    if (accounts.count() == 1) return ui.kOperationView->getShowWidget()->getAction(accounts.at(0))->toolTip();
+    foreach(const QString & item, accounts) {
+        if (item.startsWith(QLatin1String("##"))) {
+            return ui.kOperationView->getShowWidget()->getAction(item)->toolTip();
+        }
+    }
     return "";
 }
 
@@ -467,7 +464,7 @@ void SKGOperationPluginWidget::onSelectionChanged()
                         m_showClosedAccounts = true;
                         dataModified("", 0);
                     }
-                    ui.kTargetAccountEdit->setText(account2.getName());
+                    ui.kTargetAccountEdit->setText(accountName);
                     if (mode >= 0) ui.kWidgetSelector->setSelectedMode(2);
                 } else {
                     if (mode >= 0) ui.kWidgetSelector->setSelectedMode(0);
@@ -1113,6 +1110,7 @@ void SKGOperationPluginWidget::setState(const QString& iState)
     QString reconcilitorAmountS = root.attribute("reconcilitorAmount");
     QString operationTable = root.attribute("operationTable");
     QString selection = root.attribute("selection");
+    QString templates = root.attribute("template");
     m_operationWhereClause = root.attribute("operationWhereClause");
 
     //Default values in case of reset
@@ -1178,6 +1176,13 @@ void SKGOperationPluginWidget::setState(const QString& iState)
         ui.kOperationView->getShowWidget()->setState(parameters.join(";"));
     }
 
+    if (templates == "Y") {
+        QStringList parameters = SKGServices::splitCSVLine(ui.kOperationView->getShowWidget()->getState());
+        parameters.removeAll("operations");
+        parameters.push_back("templates");
+        ui.kOperationView->getShowWidget()->setState(parameters.join(";"));
+    }
+
     if (!selection.isEmpty()) {
         QStringList uuids = SKGServices::splitCSVLine(selection);
         ui.kOperationView->getView()->selectObjects(uuids, true);  //FIXME //TODO
@@ -1196,11 +1201,13 @@ void SKGOperationPluginWidget::fillTargetAccount()
 {
     int nbAccounts = ui.kAccountEdit->count();
     QString current = ui.kAccountEdit->text();
+    QString currentTarget = ui.kTargetAccountEdit->text();
     ui.kTargetAccountEdit->clear();
     for (int i = 0; i < nbAccounts; ++i) {
         if (ui.kAccountEdit->itemText(i) != current)
             ui.kTargetAccountEdit->addItem(ui.kAccountEdit->itemIcon(i), ui.kAccountEdit->itemText(i));
     }
+    if (ui.kTargetAccountEdit->contains(currentTarget)) ui.kTargetAccountEdit->setText(currentTarget);
 }
 
 void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
@@ -1271,8 +1278,11 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
                 show->addGroupedItem("templates", i18nc("Option to for display of operations", "Templates"), "skrooge_template", "d_date!='0000-00-00' AND t_template='Y'",
                                      "type");
                 show->addSeparator();
-                show->addGroupedItem("hide", i18nc("Option to for display of operations", "All"), "dialog-ok", "1=1", "checked");
+                show->addGroupedItem("hidenone", i18nc("Option to for display of operations", "All"), "dialog-ok", "1=1", "checked");
                 show->addGroupedItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok", "t_status<>'Y'", "checked");
+                show->addGroupedItem("hide1w", i18nc("Option to for display of operations", "Hide checked operations > 1 week"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 week')", "checked");
+                show->addGroupedItem("hide2w", i18nc("Option to for display of operations", "Hide checked operations > 2 weeks"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-2 week')", "checked");
+                show->addGroupedItem("hide1m", i18nc("Option to for display of operations", "Hide checked operations > 1 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 month')", "checked");
                 show->addGroupedItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-3 month')", "checked");
                 show->addGroupedItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-6 month')", "checked");
                 show->addGroupedItem("hide1y", i18nc("Option to for display of operations", "Hide checked operations > 1 year"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 year')", "checked");
@@ -1418,13 +1428,13 @@ void SKGOperationPluginWidget::onRefreshInformationZone()
                 QString s1 = doc->formatMoney(v1, unit1);
                 QString s2 = doc->formatMoney(v2, unit1);
                 QString s3 = doc->formatMoney(v3, unit1);
-                ui.kInfo->setText(i18nc("Message", "Balance: %1     Cleared: %2     In Transit: %3", s1, s2, s3));
+                ui.kInfo->setText(i18nc("Message", "Balance: %1     Checked: %2     To be Checked: %3", s1, s2, s3));
                 if (!unit2.Symbol.isEmpty() && unit2.Value) {
                     s1 = doc->formatMoney(v1, unit2);
                     s2 = doc->formatMoney(v2, unit2);
                     s3 = doc->formatMoney(v3, unit2);
                 }
-                ui.kInfo->setToolTip(i18nc("Message", "<p>Balance: %1</p><p>Cleared: %2</p><p>In Transit: %3</p>", s1, s2, s3));
+                ui.kInfo->setToolTip(i18nc("Message", "<p>Balance: %1</p><p>Checked: %2</p><p>To be Checked: %3</p>", s1, s2, s3));
             }
         } else if (m_modeInfoZone == 1) {
             //Refresh reconciliation area
