@@ -85,7 +85,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     ui.kForecastCmb->addItem(KIcon("chronometer"), i18nc("Noun", "Schedule"), 1);
     ui.kForecastCmb->addItem(KIcon("view-income-categories"), i18nc("Noun", "Budget"), 4);
 
-    ui.kWidgetSelector->addButton(KIcon("configure"), i18n("Setup Report"), i18n("Display the edition panel for report"), ui.setupWidget);
+    ui.kWidgetSelector->addButton(KIcon("configure"), i18n("Setup Report"), i18n("Display the edit panel for report"), ui.setupWidget);
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onBtnModeClicked(int)));
 
     //Set colors
@@ -158,6 +158,8 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     connect(ui.kIncomes, SIGNAL(stateChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kExpenses, SIGNAL(stateChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kTransfers, SIGNAL(stateChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
+    connect(ui.kGrouped, SIGNAL(stateChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
+    connect(ui.kTracked, SIGNAL(stateChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kForecastCmb, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kForecastValue, SIGNAL(valueChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kCorrectedBy, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
@@ -229,6 +231,8 @@ QString SKGReportPluginWidget::getState()
     root.setAttribute("incomes", ui.kIncomes->isChecked() ? "Y" : "N");
     root.setAttribute("expenses", ui.kExpenses->isChecked() ? "Y" : "N");
     root.setAttribute("transfers", ui.kTransfers->isChecked() ? "Y" : "N");
+    root.setAttribute("grouped", ui.kGrouped->isChecked() ? "Y" : "N");
+    root.setAttribute("tracked", ui.kTracked->isChecked() ? "Y" : "N");
     root.setAttribute("currentPage", SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
     root.setAttribute("tableAndGraphState", ui.kTableWithGraph->getState());
     root.setAttribute("nbLevelLines", SKGServices::intToString(m_nbLevelLines));
@@ -265,6 +269,8 @@ void SKGReportPluginWidget::setState(const QString& iState)
     QString incomes = root.attribute("incomes");
     QString expenses = root.attribute("expenses");
     QString transfers = root.attribute("transfers");
+    QString grouped = root.attribute("grouped");
+    QString tracked = root.attribute("tracked");
     QString currentPage = root.attribute("currentPage");
     QString forecast = root.attribute("forecast");
     QString forecastValue = root.attribute("forecastValue");
@@ -290,6 +296,8 @@ void SKGReportPluginWidget::setState(const QString& iState)
     if (incomes.isEmpty()) incomes = 'Y';
     if (expenses.isEmpty()) expenses = 'Y';
     if (transfers.isEmpty()) transfers = 'Y';
+    if (grouped.isEmpty()) grouped = 'Y';
+    if (tracked.isEmpty()) tracked = 'Y';
     if (currentPage.isEmpty()) currentPage = '0';
     if (forecast.isEmpty()) forecast = '0';
     if (forecastValue.isEmpty()) forecastValue = '0';
@@ -310,6 +318,8 @@ void SKGReportPluginWidget::setState(const QString& iState)
     ui.kIncomes->setChecked(incomes != "N");
     ui.kExpenses->setChecked(expenses != "N");
     ui.kTransfers->setChecked(transfers != "N");
+    ui.kGrouped->setChecked(grouped != "N");
+    ui.kTracked->setChecked(tracked != "N");
     int currentPageInt = SKGServices::stringToInt(currentPage);
     ui.kWidgetSelector->setSelectedMode(currentPageInt);
     ui.kLine->setVisible(currentPageInt >= -1);
@@ -454,6 +464,8 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
     if (ui.kIncomes->isChecked()) types.push_back(i18nc("Noun",  "incomes"));
     if (ui.kExpenses->isChecked()) types.push_back(i18nc("Noun",  "expenses"));
     if (ui.kTransfers->isChecked()) types.push_back(i18nc("Noun",  "transfers"));
+    else if (ui.kGrouped->isChecked()) types.push_back(i18nc("Noun",  "grouped"));
+    if (ui.kTracked->isChecked()) types.push_back(i18nc("Noun",  "tracked"));
 
     oTitle += i18nc("Noun",  "during '%1' for '%2'", during, types.join(" "));
 }
@@ -759,8 +771,20 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
         if (oWhereClausForPreviousData) *oWhereClausForPreviousData += condition;
     }
 
-    if (ui.kTransfers->isChecked() == false) {
-        QString condition = " AND t_TRANSFER='N'";
+    if (ui.kGrouped->isChecked() == false) {
+        QString condition = " AND i_group_id=0";
+        wc += condition;
+        if (oWhereClausForPreviousData) *oWhereClausForPreviousData += condition;
+    } else {
+        if (ui.kTransfers->isChecked() == false) {
+            QString condition = " AND t_TRANSFER='N'";
+            wc += condition;
+            if (oWhereClausForPreviousData) *oWhereClausForPreviousData += condition;
+        }
+    }
+
+    if (ui.kTracked->isChecked() == false) {
+        QString condition = " AND r_refund_id=0";
         wc += condition;
         if (oWhereClausForPreviousData) *oWhereClausForPreviousData += condition;
     }
