@@ -28,7 +28,7 @@
 #include "skgmainpanel.h"
 #include "skgtransactionmng.h"
 #include "skgdocumentbank.h"
-#include <skgsuboperationobject.h>
+#include "skgsuboperationobject.h"
 
 #include <kactioncollection.h>
 #include <kstandardaction.h>
@@ -330,7 +330,7 @@ SKGAdviceList SKGScheduledPlugin::advices() const
     }
 
     //Possible recurrent operations
-    m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.d_date>date('now','-2 month') AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND EXISTS (SELECT 1 FROM v_operation_tmp1 op2 WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.d_date=date(op2.d_date, '+1 month')) AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 op2  WHERE ro.rd_operation_id=op2.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.rc_unit_id=op2.rc_unit_id)", result);
+    m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.d_date>(SELECT date('now','-2 month')) AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND EXISTS (SELECT 1 FROM v_operation_tmp1 op2 WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.d_date=(SELECT date(op2.d_date, '+1 month'))) AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 op2  WHERE ro.rd_operation_id=op2.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.rc_unit_id=op2.rc_unit_id)", result);
     nb = result.count();
     for (int i = 1; i < nb; ++i) { //Ignore header
         //Get parameters
