@@ -27,12 +27,11 @@
 #include "skgunitobject.h"
 #include "skgmainpanel.h"
 #include "skgruleobject.h"
+#include "skgprogressbar.h"
 
 #include <kaction.h>
 
 #include <QDomDocument>
-#include <QProgressBar>
-#include <kcolorscheme.h>
 
 SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     : SKGWidget(iDocument)
@@ -112,18 +111,12 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
             SKGError err = doc->getObjects("v_rule", wc % " ORDER BY i_ORDER", rules);
             int nb = rules.count();
             if (nb) {
-                //Get std colors
-                KColorScheme scheme(QPalette::Normal);
-                QString negative = scheme.foreground(KColorScheme::NegativeText).color().name();
-                QString neutral = scheme.foreground(KColorScheme::NeutralText).color().name();
-                QString positive = scheme.foreground(KColorScheme::PositiveText).color().name();
-
                 for (int i = 0; !err && i < nb; ++i) {
                     SKGRuleObject rule = rules.at(i);
                     SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
 
                     //Create progress bar
-                    QProgressBar* progressBar = new QProgressBar(ui.kGroup);
+                    SKGProgressBar* progressBar = new SKGProgressBar(ui.kGroup);
                     progressBar->setObjectName(QString::fromUtf8("progressBar"));
                     progressBar->setMaximum(qMax(alarm.Amount, alarm.Limit));
                     progressBar->setValue(alarm.Amount);
@@ -143,10 +136,7 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                     progressBar->setToolTip(txt);
 
                     //Change color
-                    double percent = 100 * alarm.Amount / alarm.Limit;
-                    QString st = progressBar->styleSheet();
-                    st = QString(" QProgressBar { text-align: center; padding: 0.5px;} QProgressBar::chunk {text-align: center; border-radius:4px; background-color: ") % (percent < 70 ? positive : (percent > 90 ? negative : neutral)) % ";}" % st;
-                    progressBar->setStyleSheet(st);
+                    progressBar->setLimits(qMax(alarm.Amount, alarm.Limit), 0.9 * alarm.Limit, 0.7 * alarm.Limit);
 
                     //Add progress bar
                     ui.layout->addWidget(progressBar);
