@@ -31,6 +31,17 @@
 class SKGSearchPluginWidget : public SKGTabPage
 {
     Q_OBJECT
+    /**
+     * This enumerate defines the open mode
+     */
+    Q_ENUMS(OpenMode);
+public:
+    /**
+     * This enumerate defines the open mode
+     */
+    enum OpenMode {TABLE,   /**< open in a table*/
+                   REPORT   /**< open in report page*/
+                  };
 
 public:
     /**
@@ -97,8 +108,9 @@ public:
     /**
      * Open operations corresponding to a rule
      * @param iRule a rule
+     * @param iMode the mode for the open
      */
-    static void open(const SKGRuleObject& iRule);
+    static void open(const SKGRuleObject& iRule, OpenMode iMode = TABLE);
 
 protected:
     /**
@@ -113,7 +125,7 @@ private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
     void onAddRule();
     void onModifyRule();
-    void onSearch();
+    void onOpen();
     void onSelectionChanged();
     void onTop();
     void onUp();
