@@ -121,17 +121,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     menu->addAction(m_upload);
     ui.kGetNewHotStuff->setMenu(menu);
 
-    KAction* downloadMonthlyAction = new KAction(KIcon("download"), i18n("download all monthly values"), this);
-    downloadMonthlyAction->setData(SKGUnitObject::ALL_MONTHLY);
-    connect(downloadMonthlyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
-
-    KAction* downloadWeeklyAction = new KAction(KIcon("download"), i18n("download all weekly values"), this);
-    downloadWeeklyAction->setData(SKGUnitObject::ALL_WEEKLY);
-    connect(downloadWeeklyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
-
-    KAction* downloadDailyAction = new KAction(KIcon("download"), i18n("download all daily values"), this);
-    downloadDailyAction->setData(SKGUnitObject::ALL_DAILY);
-    connect(downloadDailyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+    KAction* downloadLastAction = new KAction(KIcon("download"), i18n("download last value only"), this);
+    downloadLastAction->setData(SKGUnitObject::LAST);
+    connect(downloadLastAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
 
     KAction* downloadLastMonthlyAction = new KAction(KIcon("download"), i18n("download monthly values since last known value"), this);
     downloadLastMonthlyAction->setData(SKGUnitObject::LAST_MONTHLY);
@@ -145,39 +137,51 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     downloadLastDailyAction->setData(SKGUnitObject::LAST_DAILY);
     connect(downloadLastDailyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
 
+    KAction* downloadMonthlyAction = new KAction(KIcon("download"), i18n("download all monthly values"), this);
+    downloadMonthlyAction->setData(SKGUnitObject::ALL_MONTHLY);
+    connect(downloadMonthlyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+    KAction* downloadWeeklyAction = new KAction(KIcon("download"), i18n("download all weekly values"), this);
+    downloadWeeklyAction->setData(SKGUnitObject::ALL_WEEKLY);
+    connect(downloadWeeklyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+    KAction* downloadDailyAction = new KAction(KIcon("download"), i18n("download all daily values"), this);
+    downloadDailyAction->setData(SKGUnitObject::ALL_DAILY);
+    connect(downloadDailyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
     KAction* simplifyAction = new KAction(KIcon("edit-delete"), i18n("simplify values"), this);
     connect(simplifyAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onSimplify()));
 
 
     KMenu* downloadMenu = new KMenu();
-    downloadMenu->addAction(downloadMonthlyAction);
-    downloadMenu->addAction(downloadWeeklyAction);
-    downloadMenu->addAction(downloadDailyAction);
+    downloadMenu->addAction(downloadLastAction);
     downloadMenu->addAction(downloadLastMonthlyAction);
     downloadMenu->addAction(downloadLastWeeklyAction);
     downloadMenu->addAction(downloadLastDailyAction);
+    downloadMenu->addAction(downloadMonthlyAction);
+    downloadMenu->addAction(downloadWeeklyAction);
+    downloadMenu->addAction(downloadDailyAction);
+
     downloadMenu->addAction(simplifyAction);
-
-
     ui.kUnitValueDownload->setMenu(downloadMenu);
     connect(ui.kUnitValueDownload, SIGNAL(clicked(bool)), SLOT(onDownloadUnitValue()));
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kStandardFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(KIcon("dialog-ok-apply"), i18n("Standard"), i18n("Display the edition panel for standard units"), list);
+        ui.kWidgetSelector->addButton(KIcon("dialog-ok-apply"), i18n("Standard"), i18n("Display the edit panel for standard units"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kManualFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(KIcon("user-properties"), i18n("Manual / Share"), i18n("Display the edition panel for manual units"), list);
+        ui.kWidgetSelector->addButton(KIcon("user-properties"), i18n("Manual / Share"), i18n("Display the edit panel for manual units"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kValuesFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(KIcon("view-currency-list"), i18n("Values"), i18n("Display the edition panel for values of units"), list);
+        ui.kWidgetSelector->addButton(KIcon("view-currency-list"), i18n("Values"), i18n("Display the edit panel for values of units"), list);
     }
     connect(ui.kWidgetSelector, SIGNAL(selectedModeChanged(int)), this, SLOT(onUnitCreatorModified()));
 
@@ -188,6 +192,13 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial share, as in a stock market", "Share"), SKGUnitObject::SHARE);
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), SKGUnitObject::INDEX);
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a physical object like a house or a car", "Object"), SKGUnitObject::OBJECT);
+    bool primaryUnit, secondaryUnit;
+    iDocument->existObjects("unit", "t_type='1'", primaryUnit);
+    iDocument->existObjects("unit", "t_type='2'", secondaryUnit);
+    if (primaryUnit) {
+        if (secondaryUnit) ui.kTypeCreatorUnit->setCurrentIndex(2);
+        else ui.kTypeCreatorUnit->setCurrentIndex(1);
+    } else ui.kTypeCreatorUnit->setCurrentIndex(0);
 
     //Bind unit creation view
     {
