@@ -19,8 +19,8 @@
 
 #include <Plasma/DataEngine>
 
-#include <skgdocument.h>
-#include <skgdocumentbank.h>
+#include "skgdocument.h"
+#include "skgdocumentbank.h"
 
 /**
  * This class is the skrooge dataengine. It allows fetching data
