@@ -258,6 +258,8 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
             else if (val == "A") return i18nc("Noun, a type of account", "Assets");
             else if (val == "I") return i18nc("Noun, a type of account", "Investment");
             else if (val == "W") return i18nc("Noun, a type of account", "Wallet");
+            else if (val == "L") return i18nc("Noun, a type of account", "Loan");
+            else if (val == "S") return i18nc("Noun, a type of account", "Saving");
             else return i18nc("Noun", "Other");
         } else if (m_unitTable && att == "t_type") {
             if (val == "1") return i18nc("Noun", "Primary currency");
