@@ -22,7 +22,7 @@
 #include "skgdateeditdesignerplugin.h"
 #include "skgdateedit.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
