@@ -696,6 +696,7 @@ void SKGMainPanel::setupActions()
     connect(m_previousAction, SIGNAL(triggered(bool)), this, SLOT(actionPrevious()));
     actionCollection()->addAction(QLatin1String("go_previous"), m_previousAction);
     m_previousAction->setShortcut(Qt::ALT + Qt::Key_Left);
+    m_previousAction->setPriority(QAction::LowPriority);
 
     //m_tabWidget->setCornerWidget(toolBar(), Qt::TopLeftCorner);
 
@@ -712,6 +713,7 @@ void SKGMainPanel::setupActions()
     connect(m_nextAction, SIGNAL(triggered(bool)), this, SLOT(actionNext()));
     actionCollection()->addAction(QLatin1String("go_next"), m_nextAction);
     m_nextAction->setShortcut(Qt::ALT + Qt::Key_Right);
+    m_nextAction->setPriority(QAction::LowPriority);
 
     m_nextMenu = static_cast<KMenu*>(m_nextAction->menu());
     connect(m_nextMenu , SIGNAL(aboutToShow()), this, SLOT(onShowNextMenu()));
@@ -1519,6 +1521,7 @@ void SKGMainPanel::closeAllPages(bool iForce)
         if (w && (iForce || !w->isPin())) closePage(w);
     }
     m_tabWidget->blockSignals(previous);
+    KMessageBox::enableMessage("closepinnedpage");
     Q_EMIT currentPageChanged();
 }
 
