@@ -22,9 +22,9 @@
 #include "skgshow.h"
 #include "skgservices.h"
 
-#include "klocale.h"
-#include "kmenu.h"
-#include "kicon.h"
+#include <klocale.h>
+#include <kmenu.h>
+#include <kicon.h>
 
 SKGShow::SKGShow(QWidget* parent)
     : QToolButton(parent), m_mode(OR), m_inTrigger(false), m_displayTitle(true)
