@@ -98,7 +98,7 @@ public:
      * Get the table content
      * @return the table content
      */
-    virtual SKGStringListList getTable();
+    virtual SKGStringListList getTable() const;
 
     /**
      * Get the current selection
@@ -278,6 +278,8 @@ private Q_SLOTS:
     void onActionTriggered(int action);
     void onRangeChanged();
 
+    SKGStringListList getTableContent(const QModelIndex& iIndex = QModelIndex()) const;
+
 private:
     Q_DISABLE_COPY(SKGTreeView);
     QStringList getCurrentSchema() const;
