@@ -279,7 +279,7 @@ SKGError SKGObjectBase::load()
     SKGError err;
     SKGTRACEINRC(20, "SKGObjectBase::load", err);
 
-    if (getDocument()) {
+    if (getDocument() && !getTable().isEmpty()) {
         //Prepare where clause
         QString wc = getWhereclauseId();
         if (wc.isEmpty()) wc = "id=" % SKGServices::intToString(d->id);
