@@ -712,6 +712,57 @@ SKGError SKGServices::copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& o
     return err;
 }
 
+SKGError SKGServices::copySqliteDatabaseToJson(QSqlDatabase* iDb, QString& oDocument)
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGServices::copySqliteDatabaseToXml", err);
+    if (iDb) {
+        oDocument = "{\n";
+
+        // Copy the tables
+        QStringList listTables = iDb->tables();
+        listTables.removeAll("sqlite_sequence");
+        listTables.removeAll("sqlite_stat1");
+        int nb = listTables.count();
+        for (int i = 0; !err && i < nb; ++i) {
+            QString tableName = listTables.at(i);
+
+            oDocument += "\"" % tableName % "\":\n[\n";
+
+            SKGStringListList listRows;
+            err = SKGServices::executeSelectSqliteOrder(iDb, "SELECT * FROM " % tableName, listRows);
+            int nbRows = listRows.count();
+            if (nbRows) {
+                QStringList titles = listRows.at(0);
+                for (int j = 1; !err && j < nbRows; ++j) { //Forget title
+                    QStringList values = listRows.at(j);
+
+                    oDocument += "{";
+                    int nbVals = values.count();
+                    for (int k = 0; k < nbVals; ++k) {
+		        QString v=values.at(k);
+		        v=v.replace("\\","\\\\");
+		        v=v.replace("\t","\\\t");
+		        v=v.replace("\r","\\\r");
+		        v=v.replace("\n","\\\n");
+		        v=v.replace("\f","\\\f");
+		        v=v.replace("\b","\\\b");
+		        v=v.replace("/","\\/");
+		        v=v.replace("\"","\\\"");
+                        oDocument += "\"" % titles.at(k) % "\":\"" % v % "\"";
+                        if (k < nbVals - 1) oDocument += ",";
+                    }
+                    oDocument += "}";
+                    if (j < nbRows - 1) oDocument += ",";
+                    oDocument += "\n";
+                }
+            }
+            oDocument += "]\n";
+        }
+    }
+    return err;
+}
+
 SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iMemoryDb, bool iFromFileToMemory)
 {
     SKGError err;
